@@ -16,14 +16,14 @@ import (
 	"time"
 
 	subrelv1 "github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/apis/apps/v1"
-	operatorsv1 "github.com/open-cluster-management/multiclusterhub-operator/pkg/apis/operator/v1"
-	"github.com/open-cluster-management/multiclusterhub-operator/pkg/channel"
-	"github.com/open-cluster-management/multiclusterhub-operator/pkg/foundation"
-	"github.com/open-cluster-management/multiclusterhub-operator/pkg/helmrepo"
-	"github.com/open-cluster-management/multiclusterhub-operator/pkg/manifest"
-	"github.com/open-cluster-management/multiclusterhub-operator/pkg/subscription"
-	"github.com/open-cluster-management/multiclusterhub-operator/pkg/utils"
-	"github.com/open-cluster-management/multiclusterhub-operator/version"
+	operatorsv1 "github.com/stolostron/multiclusterhub-operator/pkg/apis/operator/v1"
+	"github.com/stolostron/multiclusterhub-operator/pkg/channel"
+	"github.com/stolostron/multiclusterhub-operator/pkg/foundation"
+	"github.com/stolostron/multiclusterhub-operator/pkg/helmrepo"
+	"github.com/stolostron/multiclusterhub-operator/pkg/manifest"
+	"github.com/stolostron/multiclusterhub-operator/pkg/subscription"
+	"github.com/stolostron/multiclusterhub-operator/pkg/utils"
+	"github.com/stolostron/multiclusterhub-operator/version"
 
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
