@@ -7,7 +7,7 @@ import (
 	"reflect"
 	"testing"
 
-	operatorsv1 "github.com/open-cluster-management/multiclusterhub-operator/pkg/apis/operator/v1"
+	operatorsv1 "github.com/stolostron/multiclusterhub-operator/pkg/apis/operator/v1"
 	corev1 "k8s.io/api/core/v1"
 	v1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -181,7 +181,7 @@ func TestGetImagePullPolicy(t *testing.T) {
 	}
 
 	t.Run("No pull policy set", func(t *testing.T) {
-		want := v1.PullAlways
+		want := v1.PullIfNotPresent
 		if got := GetImagePullPolicy(noPullPolicyMCH); got != want {
 			t.Errorf("GetImagePullPolicy() = %v, want %v", got, want)
 		}
