@@ -17,7 +17,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 
-	utils "github.com/open-cluster-management/multiclusterhub-operator/test/utils"
+	utils "github.com/stolostron/multiclusterhub-operator/test/utils"
 )
 
 var _ = Describe("Multiclusterhub", func() {
@@ -138,6 +138,20 @@ func FullInstallTestSuite() {
 		return
 	})
 
+	It("Test PullPolicy", func() {
+		By("- When creating the MCH, ensure that all deployments use the IfNotPresent pullPolicy")
+
+		utils.CreateMCHNotManaged()
+		err := utils.ValidateMCH()
+		Expect(err).To(BeNil())
+
+		By("- listing each deployment in the MCH namespace and checking")
+
+		err = utils.ValidateDeploymentPolicies()
+		Expect(err).To(BeNil())
+
+	})
+
 	It("Testing Image Overrides Configmap", func() {
 		By("- If configmap is manually overwitten, ensure MCH Operator will overwrite")
 
@@ -150,7 +164,7 @@ func FullInstallTestSuite() {
 		Expect(err).To(BeNil())
 		v, err := semver.NewVersion(currentVersion)
 		Expect(err).Should(BeNil())
-		c, err := semver.NewConstraint(">= 2.3.4")
+		c, err := semver.NewConstraint(">= 2.3.9")
 		Expect(err).Should(BeNil())
 
 		if c.Check(v) {
@@ -192,7 +206,7 @@ func FullInstallTestSuite() {
 					{
 					  "image-name": "application-ui",
 					  "image-tag": "not-a-real-tag",
-					  "image-remote": "quay.io/open-cluster-management",
+					  "image-remote": "quay.io/stolostron",
 					  "image-key": "application_ui"
 					}
 				  ]`,
@@ -205,7 +219,7 @@ func FullInstallTestSuite() {
 
 		v, err := semver.NewVersion(currentVersion)
 		Expect(err).Should(BeNil())
-		c, err := semver.NewConstraint(">= 2.3.4")
+		c, err := semver.NewConstraint(">= 2.3.9")
 		Expect(err).Should(BeNil())
 		if c.Check(v) {
 			_, err = utils.KubeClient.CoreV1().ConfigMaps(utils.MCHNamespace).Create(context.TODO(), configmap, metav1.CreateOptions{})
@@ -221,7 +235,7 @@ func FullInstallTestSuite() {
 				if len(configmap.Data) == 0 {
 					return fmt.Errorf("Configmap has not been updated")
 				}
-				if configmap.Data["application_ui"] != "quay.io/open-cluster-management/application-ui:not-a-real-tag" {
+				if configmap.Data["application_ui"] != "quay.io/stolostron/application-ui:not-a-real-tag" {
 					return fmt.Errorf("Configmap has not been updated from overrides CM.")
 				}
 				return nil
