@@ -12,7 +12,7 @@ import (
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
 
-	utils "github.com/open-cluster-management/multiclusterhub-operator/test/utils"
+	utils "github.com/stolostron/multiclusterhub-operator/test/utils"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/klog"
@@ -92,7 +92,7 @@ var _ = Describe("Multiclusterhub", func() {
 		updateVersion, err := semver.NewVersion(os.Getenv(("updateVersion")))
 		Expect(err).Should(BeNil())
 
-		c, err := semver.NewConstraint(">= 2.3.4")
+		c, err := semver.NewConstraint(">= 2.3.9")
 		Expect(err).Should(BeNil())
 		configmapCount := 0
 		if c.Check(startVersion) {
